@@ -21,23 +21,31 @@
 #ifndef __XFPM_COMMON_H
 #define __XFPM_COMMON_H
 
-#include <glib.h>
 #include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
-GdkPixbuf      *xfpm_icon_load                  (const gchar *icon_name,
-                                                 gint         size,
-                                                 gint         scale_factor);
-const gchar    *xfpm_bool_to_string             (gboolean     value) G_GNUC_PURE;
-gboolean        xfpm_string_to_bool             (const gchar *string) G_GNUC_PURE;
-GtkBuilder     *xfpm_builder_new_from_string    (const gchar *file,
-                                                 GError     **error);
-void            xfpm_preferences                (void);
-void            xfpm_preferences_device_id      (const gchar *object_path);
-void            xfpm_quit                       (void);
-void            xfpm_about                      (gpointer     data);
-gboolean        xfpm_is_multihead_connected     (void);
+GdkPixbuf *
+xfpm_icon_load (const gchar *icon_name,
+                gint size,
+                gint scale_factor);
+const gchar *
+xfpm_bool_to_string (gboolean value) G_GNUC_PURE;
+gboolean
+xfpm_string_to_bool (const gchar *string) G_GNUC_PURE;
+GtkBuilder *
+xfpm_builder_new_from_string (const gchar *file,
+                              GError **error);
+void
+xfpm_preferences (void);
+void
+xfpm_preferences_device_id (const gchar *object_path);
+void
+xfpm_quit (void);
+void
+xfpm_about (gpointer data);
+gboolean
+xfpm_is_multihead_connected (GObject *lifetime);
 
 G_END_DECLS
 
