@@ -21,6 +21,8 @@
 #ifndef __XFPM_ENUM_GLIB_H
 #define __XFPM_ENUM_GLIB_H
 
+#include <glib.h>
+
 G_BEGIN_DECLS
 
 /*
@@ -31,7 +33,8 @@ typedef enum
   XFPM_BATTERY_CHARGE_UNKNOWN,
   XFPM_BATTERY_CHARGE_CRITICAL,
   XFPM_BATTERY_CHARGE_LOW,
-  XFPM_BATTERY_CHARGE_OK
+  XFPM_BATTERY_CHARGE_OK,
+  N_XFPM_BATTERY_CHARGES
 } XfpmBatteryCharge;
 
 typedef enum
@@ -40,7 +43,9 @@ typedef enum
   XFPM_DO_SUSPEND,
   XFPM_DO_HIBERNATE,
   XFPM_ASK,
-  XFPM_DO_SHUTDOWN
+  XFPM_DO_SHUTDOWN,
+  XFPM_DO_HYBRID_SLEEP,
+  N_XFPM_SHUTDOWN_REQUESTS
 } XfpmShutdownRequest;
 
 typedef enum
@@ -50,6 +55,9 @@ typedef enum
   LID_TRIGGER_HIBERNATE,
   LID_TRIGGER_LOCK_SCREEN,
   LID_TRIGGER_NOTHING,
+  LID_TRIGGER_HYBRID_SLEEP,
+  LID_TRIGGER_SHUTDOWN,
+  N_LID_TRIGGERS
 } XfpmLidTriggerAction;
 
 typedef enum
@@ -64,7 +72,8 @@ typedef enum
   BUTTON_BATTERY,
   BUTTON_KBD_BRIGHTNESS_UP,
   BUTTON_KBD_BRIGHTNESS_DOWN,
-  NUMBER_OF_BUTTONS
+  BUTTON_KBD_BRIGHTNESS_CYCLE,
+  N_XFPM_BUTTON_KEYS
 } XfpmButtonKey;
 
 typedef enum
@@ -72,7 +81,8 @@ typedef enum
   SPIN_DOWN_HDD_NEVER,
   SPIN_DOWN_HDD_ON_BATTERY,
   SPIN_DOWN_HDD_PLUGGED_IN,
-  SPIN_DOWN_HDD_ALWAYS
+  SPIN_DOWN_HDD_ALWAYS,
+  N_SPIN_DOWN_HDDS
 } XfpmSpindownRequest;
 
 typedef enum
@@ -80,7 +90,8 @@ typedef enum
   SHOW_ICON_ALWAYS,
   SHOW_ICON_WHEN_BATTERY_PRESENT,
   SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING,
-  NEVER_SHOW_ICON
+  SHOW_ICON_NEVER,
+  N_SHOW_ICONS
 } XfpmShowIcon;
 
 typedef enum
