@@ -20,16 +20,18 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include <libxfce4util/libxfce4util.h>
-
 #include "xfpm-settings-app.h"
 
-int main (int argc, char **argv)
+#include <libxfce4util/libxfce4util.h>
+
+int
+main (int argc,
+      char **argv)
 {
-  xfce_textdomain(GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
+  xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
 
   return g_application_run (G_APPLICATION (xfpm_settings_app_new ()), argc, argv);
 }
