@@ -20,33 +20,26 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include <stdio.h>
-#ifdef HAVE_STDLIB_H
-#include <stdlib.h>
-#endif
-#ifdef HAVE_STRING_H
-#include <string.h>
-#endif
-
-#include <glib.h>
-#include <libxfce4util/libxfce4util.h>
-
 #include "xfpm-xfconf.h"
-#include "xfpm-config.h"
-#include "xfpm-enum-glib.h"
-#include "xfpm-enum.h"
-#include "xfpm-enum-types.h"
-#include "xfpm-debug.h"
 
-static void xfpm_xfconf_finalize   (GObject *object);
+#include "common/xfpm-config.h"
+#include "common/xfpm-debug.h"
+#include "common/xfpm-enum-glib.h"
+#include "common/xfpm-enum-types.h"
+#include "common/xfpm-enum.h"
+
+#include <libxfce4util/libxfce4util.h>
+
+static void
+xfpm_xfconf_finalize (GObject *object);
 
 struct XfpmXfconfPrivate
 {
-  XfconfChannel   *channel;
-  GValue          *values;
+  XfconfChannel *channel;
+  GValue *values;
 };
 
 enum
@@ -107,20 +100,16 @@ xfpm_xfconf_set_property (GObject *object,
                           const GValue *value,
                           GParamSpec *pspec)
 {
-  XfpmXfconf *conf;
-  GValue *dst;
+  XfpmXfconf *conf = XFPM_XFCONF (object);
+  GValue *dst = conf->priv->values + prop_id;
 
-  conf = XFPM_XFCONF (object);
-
-  dst = conf->priv->values + prop_id;
-
-  if ( !G_IS_VALUE (dst) )
+  if (!G_IS_VALUE (dst))
   {
     g_value_init (dst, pspec->value_type);
     g_param_value_set_default (pspec, dst);
   }
 
-  if ( g_param_values_cmp (pspec, value, dst) != 0)
+  if (g_param_values_cmp (pspec, value, dst) != 0)
   {
     g_value_copy (value, dst);
     g_object_notify (object, pspec->name);
@@ -133,14 +122,10 @@ xfpm_xfconf_get_property (GObject *object,
                           GValue *value,
                           GParamSpec *pspec)
 {
-  XfpmXfconf *conf;
-  GValue *src;
+  XfpmXfconf *conf = XFPM_XFCONF (object);
+  GValue *src = conf->priv->values + prop_id;
 
-  conf = XFPM_XFCONF (object);
-
-  src = conf->priv->values + prop_id;
-
-  if ( G_VALUE_HOLDS (src, pspec->value_type) )
+  if (G_VALUE_HOLDS (src, pspec->value_type))
     g_value_copy (src, value);
   else
     g_param_value_set_default (pspec, value);
@@ -149,14 +134,11 @@ xfpm_xfconf_get_property (GObject *object,
 static void
 xfpm_xfconf_load (XfpmXfconf *conf)
 {
-  GParamSpec **specs;
-  GValue value = { 0, };
   guint nspecs;
-  guint i;
+  GParamSpec **specs = g_object_class_list_properties (G_OBJECT_GET_CLASS (conf), &nspecs);
+  GValue value = G_VALUE_INIT;
 
-  specs = g_object_class_list_properties (G_OBJECT_GET_CLASS (conf), &nspecs);
-
-  for ( i = 0; i < nspecs; i++)
+  for (guint i = 0; i < nspecs; i++)
   {
     gchar *prop_name;
     prop_name = g_strdup_printf ("%s%s", XFPM_PROPERTIES_PREFIX, specs[i]->name);
@@ -164,7 +146,7 @@ xfpm_xfconf_load (XfpmXfconf *conf)
 
     if (conf->priv->channel != NULL)
     {
-      if ( !xfconf_channel_get_property (conf->priv->channel, prop_name, &value) )
+      if (!xfconf_channel_get_property (conf->priv->channel, prop_name, &value))
       {
         XFPM_DEBUG ("Using default configuration for %s", specs[i]->name);
         g_param_value_set_default (specs[i], &value);
@@ -179,27 +161,31 @@ xfpm_xfconf_load (XfpmXfconf *conf)
     g_object_set_property (G_OBJECT (conf), specs[i]->name, &value);
     g_value_unset (&value);
   }
+
   g_free (specs);
 }
 
 static void
-xfpm_xfconf_property_changed_cb (XfconfChannel *channel, gchar *property,
-         GValue *value, XfpmXfconf *conf)
+xfpm_xfconf_property_changed_cb (XfconfChannel *channel,
+                                 gchar *property,
+                                 GValue *value,
+                                 XfpmXfconf *conf)
 {
   /*FIXME: Set default for this key*/
-  if ( G_VALUE_TYPE(value) == G_TYPE_INVALID )
+  if (G_VALUE_TYPE (value) == G_TYPE_INVALID)
     return;
 
-  if ( !g_str_has_prefix (property, XFPM_PROPERTIES_PREFIX) || strlen (property) <= strlen (XFPM_PROPERTIES_PREFIX) )
+  if (!g_str_has_prefix (property, XFPM_PROPERTIES_PREFIX)
+      || strlen (property) <= strlen (XFPM_PROPERTIES_PREFIX))
     return;
 
   /* We handle presentation mode in xfpm-power directly */
-  if ( g_strcmp0 (property, XFPM_PROPERTIES_PREFIX PRESENTATION_MODE) == 0 )
+  if (g_strcmp0 (property, XFPM_PROPERTIES_PREFIX PRESENTATION_MODE) == 0)
     return;
 
   /* We handle brightness switch in xfpm-backlight directly */
-  if ( g_strcmp0 (property, XFPM_PROPERTIES_PREFIX BRIGHTNESS_SWITCH) == 0 ||
-       g_strcmp0 (property, XFPM_PROPERTIES_PREFIX BRIGHTNESS_SWITCH_SAVE) == 0 )
+  if (g_strcmp0 (property, XFPM_PROPERTIES_PREFIX BRIGHTNESS_SWITCH) == 0
+      || g_strcmp0 (property, XFPM_PROPERTIES_PREFIX BRIGHTNESS_SWITCH_RESTORE_ON_EXIT) == 0)
     return;
 
   XFPM_DEBUG ("Property modified: %s\n", property);
@@ -210,11 +196,10 @@ xfpm_xfconf_property_changed_cb (XfconfChannel *channel, gchar *property,
 static void
 xfpm_xfconf_class_init (XfpmXfconfClass *klass)
 {
-  GObjectClass *object_class = G_OBJECT_CLASS(klass);
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->set_property = xfpm_xfconf_set_property;
   object_class->get_property = xfpm_xfconf_get_property;
-
   object_class->finalize = xfpm_xfconf_finalize;
 
   /**
@@ -222,18 +207,18 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_GENERAL_NOTIFICATION,
-                                   g_param_spec_boolean (GENERAL_NOTIFICATION_CFG,
+                                   g_param_spec_boolean (GENERAL_NOTIFICATION,
                                                          NULL, NULL,
-                                                         TRUE,
+                                                         DEFAULT_GENERAL_NOTIFICATION,
                                                          G_PARAM_READWRITE));
   /**
    * XfpmXfconf::lock-screen-suspend-hibernate
    **/
   g_object_class_install_property (object_class,
                                    PROP_LOCK_SCREEN_ON_SLEEP,
-                                   g_param_spec_boolean (LOCK_SCREEN_ON_SLEEP,
+                                   g_param_spec_boolean (LOCK_SCREEN_SUSPEND_HIBERNATE,
                                                          NULL, NULL,
-                                                         TRUE,
+                                                         DEFAULT_LOCK_SCREEN_SUSPEND_HIBERNATE,
                                                          G_PARAM_READWRITE));
 
   /**
@@ -243,9 +228,9 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_CRITICAL_LEVEL,
                                    g_param_spec_uint (CRITICAL_POWER_LEVEL,
                                                       NULL, NULL,
-                                                      1,
-                                                      20,
-                                                      5,
+                                                      MIN_CRITICAL_POWER_LEVEL,
+                                                      MAX_CRITICAL_POWER_LEVEL,
+                                                      DEFAULT_CRITICAL_POWER_LEVEL,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -255,7 +240,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_SHOW_BRIGHTNESS_POPUP,
                                    g_param_spec_boolean (SHOW_BRIGHTNESS_POPUP,
                                                          NULL, NULL,
-                                                         TRUE,
+                                                         DEFAULT_SHOW_BRIGHTNESS_POPUP,
                                                          G_PARAM_READWRITE));
 
   /**
@@ -265,7 +250,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_HANDLE_BRIGHTNESS_KEYS,
                                    g_param_spec_boolean (HANDLE_BRIGHTNESS_KEYS,
                                                          NULL, NULL,
-                                                         TRUE,
+                                                         DEFAULT_HANDLE_BRIGHTNESS_KEYS,
                                                          G_PARAM_READWRITE));
 
   /**
@@ -275,9 +260,9 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_BRIGHTNESS_STEP_COUNT,
                                    g_param_spec_uint (BRIGHTNESS_STEP_COUNT,
                                                       NULL, NULL,
-                                                      2,
-                                                      100,
-                                                      10,
+                                                      MIN_BRIGHTNESS_STEP_COUNT,
+                                                      MAX_BRIGHTNESS_STEP_COUNT,
+                                                      DEFAULT_BRIGHTNESS_STEP_COUNT,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -287,7 +272,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_BRIGHTNESS_EXPONENTIAL,
                                    g_param_spec_boolean (BRIGHTNESS_EXPONENTIAL,
                                                          NULL, NULL,
-                                                         FALSE,
+                                                         DEFAULT_BRIGHTNESS_EXPONENTIAL,
                                                          G_PARAM_READWRITE));
 
   /**
@@ -295,11 +280,11 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_TRAY_ICON,
-                                   g_param_spec_uint (SHOW_TRAY_ICON_CFG,
+                                   g_param_spec_uint (SHOW_TRAY_ICON,
                                                       NULL, NULL,
-                                                      SHOW_ICON_ALWAYS,
-                                                      NEVER_SHOW_ICON,
-                                                      SHOW_ICON_WHEN_BATTERY_PRESENT,
+                                                      0,
+                                                      N_SHOW_ICONS - 1,
+                                                      DEFAULT_SHOW_TRAY_ICON,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -307,10 +292,10 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_CRITICAL_BATTERY_ACTION,
-                                   g_param_spec_uint (CRITICAL_BATT_ACTION_CFG,
+                                   g_param_spec_uint (CRITICAL_POWER_ACTION,
                                                       NULL, NULL,
-                                                      XFPM_DO_NOTHING,
-                                                      XFPM_DO_SHUTDOWN,
+                                                      0,
+                                                      N_XFPM_SHUTDOWN_REQUESTS - 1,
                                                       XFPM_DO_NOTHING,
                                                       G_PARAM_READWRITE));
   /**
@@ -318,11 +303,11 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_POWER_BUTTON,
-                                   g_param_spec_uint (POWER_SWITCH_CFG,
+                                   g_param_spec_uint (POWER_BUTTON_ACTION,
                                                       NULL, NULL,
-                                                      XFPM_DO_NOTHING,
-                                                      XFPM_DO_SHUTDOWN,
-                                                      XFPM_DO_NOTHING,
+                                                      0,
+                                                      N_XFPM_SHUTDOWN_REQUESTS - 1,
+                                                      DEFAULT_POWER_BUTTON_ACTION,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -330,11 +315,11 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_SLEEP_BUTTON,
-                                   g_param_spec_uint (SLEEP_SWITCH_CFG,
+                                   g_param_spec_uint (SLEEP_BUTTON_ACTION,
                                                       NULL, NULL,
-                                                      XFPM_DO_NOTHING,
-                                                      XFPM_DO_SHUTDOWN,
-                                                      XFPM_DO_NOTHING,
+                                                      0,
+                                                      N_XFPM_SHUTDOWN_REQUESTS - 1,
+                                                      DEFAULT_SLEEP_BUTTON_ACTION,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -342,11 +327,11 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_HIBERNATE_BUTTON,
-                                   g_param_spec_uint (HIBERNATE_SWITCH_CFG,
+                                   g_param_spec_uint (HIBERNATE_BUTTON_ACTION,
                                                       NULL, NULL,
-                                                      XFPM_DO_NOTHING,
-                                                      XFPM_DO_SHUTDOWN,
-                                                      XFPM_DO_NOTHING,
+                                                      0,
+                                                      N_XFPM_SHUTDOWN_REQUESTS - 1,
+                                                      DEFAULT_HIBERNATE_BUTTON_ACTION,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -354,11 +339,11 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_BATTERY_BUTTON,
-                                   g_param_spec_uint (BATTERY_SWITCH_CFG,
+                                   g_param_spec_uint (BATTERY_BUTTON_ACTION,
                                                       NULL, NULL,
-                                                      XFPM_DO_NOTHING,
-                                                      XFPM_DO_SHUTDOWN,
-                                                      XFPM_DO_NOTHING,
+                                                      0,
+                                                      N_XFPM_SHUTDOWN_REQUESTS - 1,
+                                                      DEFAULT_BATTERY_BUTTON_ACTION,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -366,23 +351,23 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_LID_ACTION_ON_AC,
-                                   g_param_spec_uint (LID_SWITCH_ON_AC_CFG,
+                                   g_param_spec_uint (LID_ACTION_ON_AC,
                                                       NULL, NULL,
-                                                      LID_TRIGGER_DPMS,
-                                                      LID_TRIGGER_NOTHING,
-                                                      LID_TRIGGER_LOCK_SCREEN,
+                                                      0,
+                                                      N_LID_TRIGGERS - 1,
+                                                      DEFAULT_LID_ACTION_ON_AC,
                                                       G_PARAM_READWRITE));
 
-   /**
+  /**
    * XfpmXfconf::brightness-level-on-ac
    **/
   g_object_class_install_property (object_class,
                                    PROP_BRIGHTNESS_LEVEL_ON_AC,
-                                   g_param_spec_uint  (BRIGHTNESS_LEVEL_ON_AC,
+                                   g_param_spec_uint (BRIGHTNESS_LEVEL_ON_AC,
                                                       NULL, NULL,
                                                       1,
                                                       100,
-                                                      80,
+                                                      DEFAULT_BRIGHTNESS_LEVEL_ON_AC,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -390,11 +375,11 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_BRIGHTNESS_LEVEL_ON_BATTERY,
-                                   g_param_spec_uint  (BRIGHTNESS_LEVEL_ON_BATTERY,
+                                   g_param_spec_uint (BRIGHTNESS_LEVEL_ON_BATTERY,
                                                       NULL, NULL,
                                                       1,
                                                       100,
-                                                      20,
+                                                      DEFAULT_BRIGHTNESS_LEVEL_ON_BATTERY,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -402,11 +387,11 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_LID_ACTION_ON_BATTERY,
-                                   g_param_spec_uint (LID_SWITCH_ON_BATTERY_CFG,
+                                   g_param_spec_uint (LID_ACTION_ON_BATTERY,
                                                       NULL, NULL,
-                                                      LID_TRIGGER_DPMS,
-                                                      LID_TRIGGER_NOTHING,
-                                                      LID_TRIGGER_LOCK_SCREEN,
+                                                      0,
+                                                      N_LID_TRIGGERS - 1,
+                                                      DEFAULT_LID_ACTION_ON_BATTERY,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -414,74 +399,74 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_ENABLE_DPMS,
-                                   g_param_spec_boolean (DPMS_ENABLED_CFG,
+                                   g_param_spec_boolean (DPMS_ENABLED,
                                                          NULL, NULL,
-                                                         TRUE,
+                                                         DEFAULT_DPMS_ENABLED,
                                                          G_PARAM_READWRITE));
   /**
    * XfpmXfconf::dpms-on-ac-sleep
    **/
   g_object_class_install_property (object_class,
                                    PROP_DPMS_SLEEP_ON_AC,
-                                   g_param_spec_uint (ON_AC_DPMS_SLEEP,
+                                   g_param_spec_uint (DPMS_ON_AC_SLEEP,
                                                       NULL, NULL,
                                                       0,
-                                                      G_MAXUINT16,
-                                                      10,
+                                                      G_MAXUINT,
+                                                      DEFAULT_DPMS_ON_AC_SLEEP,
                                                       G_PARAM_READWRITE));
   /**
    * XfpmXfconf::dpms-on-ac-off
    **/
   g_object_class_install_property (object_class,
                                    PROP_DPMS_OFF_ON_AC,
-                                   g_param_spec_uint (ON_AC_DPMS_OFF,
+                                   g_param_spec_uint (DPMS_ON_AC_OFF,
                                                       NULL, NULL,
                                                       0,
-                                                      G_MAXUINT16,
-                                                      15,
+                                                      G_MAXUINT,
+                                                      DEFAULT_DPMS_ON_AC_OFF,
                                                       G_PARAM_READWRITE));
   /**
    * XfpmXfconf::dpms-on-battery-sleep
    **/
   g_object_class_install_property (object_class,
                                    PROP_DPMS_SLEEP_ON_BATTERY,
-                                   g_param_spec_uint (ON_BATT_DPMS_SLEEP,
+                                   g_param_spec_uint (DPMS_ON_BATTERY_SLEEP,
                                                       NULL, NULL,
                                                       0,
-                                                      G_MAXUINT16,
-                                                      5,
+                                                      G_MAXUINT,
+                                                      DEFAULT_DPMS_ON_BATTERY_SLEEP,
                                                       G_PARAM_READWRITE));
   /**
    * XfpmXfconf::dpms-on-battery-off
    **/
   g_object_class_install_property (object_class,
                                    PROP_DPMS_OFF_ON_BATTERY,
-                                   g_param_spec_uint (ON_BATT_DPMS_OFF,
+                                   g_param_spec_uint (DPMS_ON_BATTERY_OFF,
                                                       NULL, NULL,
                                                       0,
-                                                      G_MAXUINT16,
-                                                      10,
+                                                      G_MAXUINT,
+                                                      DEFAULT_DPMS_ON_BATTERY_OFF,
                                                       G_PARAM_READWRITE));
   /**
    * XfpmXfconf::dpms-sleep-mode
    **/
   g_object_class_install_property (object_class,
                                    PROP_DPMS_SLEEP_MODE,
-                                   g_param_spec_string  (DPMS_SLEEP_MODE,
-                                                         NULL, NULL,
-                                                         "Standby",
-                                                         G_PARAM_READWRITE));
+                                   g_param_spec_string (DPMS_SLEEP_MODE,
+                                                        NULL, NULL,
+                                                        DEFAULT_DPMS_SLEEP_MODE,
+                                                        G_PARAM_READWRITE));
 
   /**
    * XfpmXfconf::inactivity-on-ac
    **/
   g_object_class_install_property (object_class,
                                    PROP_IDLE_ON_AC,
-                                   g_param_spec_uint (ON_AC_INACTIVITY_TIMEOUT,
+                                   g_param_spec_uint (INACTIVITY_ON_AC,
                                                       NULL, NULL,
                                                       0,
                                                       G_MAXUINT,
-                                                      14,
+                                                      DEFAULT_INACTIVITY_ON_AC,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -489,11 +474,11 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_IDLE_ON_BATTERY,
-                                   g_param_spec_uint (ON_BATTERY_INACTIVITY_TIMEOUT,
+                                   g_param_spec_uint (INACTIVITY_ON_BATTERY,
                                                       NULL, NULL,
                                                       0,
                                                       G_MAXUINT,
-                                                      14,
+                                                      DEFAULT_INACTIVITY_ON_BATTERY,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -505,7 +490,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                       NULL, NULL,
                                                       XFPM_DO_SUSPEND,
                                                       XFPM_DO_HIBERNATE,
-                                                      XFPM_DO_HIBERNATE,
+                                                      DEFAULT_INACTIVITY_SLEEP_MODE_ON_BATTERY,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -517,7 +502,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                       NULL, NULL,
                                                       XFPM_DO_SUSPEND,
                                                       XFPM_DO_HIBERNATE,
-                                                      XFPM_DO_SUSPEND,
+                                                      DEFAULT_INACTIVITY_SLEEP_MODE_ON_AC,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -527,9 +512,9 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_DIM_ON_AC_TIMEOUT,
                                    g_param_spec_uint (BRIGHTNESS_ON_AC,
                                                       NULL, NULL,
-                                                      9,
+                                                      MIN_BRIGHTNESS_ON_AC,
                                                       G_MAXUINT,
-                                                      9,
+                                                      DEFAULT_BRIGHTNESS_ON_AC,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -539,9 +524,9 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_DIM_ON_BATTERY_TIMEOUT,
                                    g_param_spec_uint (BRIGHTNESS_ON_BATTERY,
                                                       NULL, NULL,
-                                                      9,
+                                                      MIN_BRIGHTNESS_ON_BATTERY,
                                                       G_MAXUINT,
-                                                      300,
+                                                      DEFAULT_BRIGHTNESS_ON_BATTERY,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -549,19 +534,19 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_PROFILE_ON_AC,
-                                   g_param_spec_string  (PROFILE_ON_AC,
-                                                         NULL, NULL,
-                                                         NULL,
-                                                         G_PARAM_READWRITE));
+                                   g_param_spec_string (PROFILE_ON_AC,
+                                                        NULL, NULL,
+                                                        DEFAULT_PROFILE_ON_AC,
+                                                        G_PARAM_READWRITE));
   /**
    * XfpmXfconf::profile-on-ac
    **/
   g_object_class_install_property (object_class,
                                    PROP_PROFILE_ON_BATTERY,
-                                   g_param_spec_string  (PROFILE_ON_BATTERY,
-                                                         NULL, NULL,
-                                                         NULL,
-                                                         G_PARAM_READWRITE));
+                                   g_param_spec_string (PROFILE_ON_BATTERY,
+                                                        NULL, NULL,
+                                                        DEFAULT_PROFILE_ON_BATTERY,
+                                                        G_PARAM_READWRITE));
 
 
   /**
@@ -571,9 +556,9 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_BRIGHTNESS_SLIDER_MIN_LEVEL,
                                    g_param_spec_int (BRIGHTNESS_SLIDER_MIN_LEVEL,
                                                      NULL, NULL,
-                                                     -1,
-                                                     G_MAXINT32,
-                                                     -1,
+                                                     MIN_BRIGHTNESS_SLIDER_MIN_LEVEL,
+                                                     G_MAXINT,
+                                                     DEFAULT_BRIGHTNESS_SLIDER_MIN_LEVEL,
                                                      G_PARAM_READWRITE));
 
   /**
@@ -583,7 +568,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_LOGIND_HANDLE_POWER_KEY,
                                    g_param_spec_boolean (LOGIND_HANDLE_POWER_KEY,
                                                          NULL, NULL,
-                                                         FALSE,
+                                                         DEFAULT_LOGIND_HANDLE_POWER_KEY,
                                                          G_PARAM_READWRITE));
 
   /**
@@ -593,7 +578,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_LOGIND_HANDLE_SUSPEND_KEY,
                                    g_param_spec_boolean (LOGIND_HANDLE_SUSPEND_KEY,
                                                          NULL, NULL,
-                                                         FALSE,
+                                                         DEFAULT_LOGIND_HANDLE_SUSPEND_KEY,
                                                          G_PARAM_READWRITE));
 
   /**
@@ -603,7 +588,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_LOGIND_HANDLE_HIBERNATE_KEY,
                                    g_param_spec_boolean (LOGIND_HANDLE_HIBERNATE_KEY,
                                                          NULL, NULL,
-                                                         FALSE,
+                                                         DEFAULT_LOGIND_HANDLE_HIBERNATE_KEY,
                                                          G_PARAM_READWRITE));
 
   /**
@@ -613,7 +598,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_LOGIND_HANDLE_LID_SWITCH,
                                    g_param_spec_boolean (LOGIND_HANDLE_LID_SWITCH,
                                                          NULL, NULL,
-                                                         FALSE,
+                                                         DEFAULT_LOGIND_HANDLE_LID_SWITCH,
                                                          G_PARAM_READWRITE));
 
   /**
@@ -621,10 +606,10 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
    **/
   g_object_class_install_property (object_class,
                                    PROP_HEARTBEAT_COMMAND,
-                                   g_param_spec_string  (HEARTBEAT_COMMAND,
-                                                         NULL, NULL,
-                                                         NULL,
-                                                         G_PARAM_READWRITE));
+                                   g_param_spec_string (HEARTBEAT_COMMAND,
+                                                        NULL, NULL,
+                                                        DEFAULT_HEARTBEAT_COMMAND,
+                                                        G_PARAM_READWRITE));
 
   /**
    * XfpmXfconf::show-panel-label
@@ -633,9 +618,9 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_SHOW_PANEL_LABEL,
                                    g_param_spec_int (SHOW_PANEL_LABEL,
                                                      NULL, NULL,
-                                                     PANEL_LABEL_NONE,
-                                                     PANEL_LABEL_PERCENTAGE_AND_TIME,
-                                                     PANEL_LABEL_PERCENTAGE,
+                                                     0,
+                                                     N_PANEL_LABELS - 1,
+                                                     DEFAULT_SHOW_PANEL_LABEL,
                                                      G_PARAM_READWRITE));
 
   /**
@@ -645,7 +630,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_SHOW_PRESENTATION_INDICATOR,
                                    g_param_spec_boolean (SHOW_PRESENTATION_INDICATOR,
                                                          NULL, NULL,
-                                                         FALSE,
+                                                         DEFAULT_SHOW_PRESENTATION_INDICATOR,
                                                          G_PARAM_READWRITE));
 }
 
@@ -655,14 +640,13 @@ xfpm_xfconf_init (XfpmXfconf *conf)
   GError *error = NULL;
 
   conf->priv = xfpm_xfconf_get_instance_private (conf);
-
   conf->priv->values = g_new0 (GValue, N_PROPERTIES);
 
-  if ( !xfconf_init (&error) )
+  if (!xfconf_init (&error))
   {
     if (error)
     {
-      g_critical ("xfconf_init failed: %s\n", error->message);
+      g_critical ("xfconf_init failed: %s", error->message);
       g_error_free (error);
     }
   }
@@ -676,25 +660,21 @@ xfpm_xfconf_init (XfpmXfconf *conf)
 }
 
 static void
-xfpm_xfconf_finalize(GObject *object)
+xfpm_xfconf_finalize (GObject *object)
 {
-  XfpmXfconf *conf;
-  guint i;
+  XfpmXfconf *conf = XFPM_XFCONF (object);
 
-  conf = XFPM_XFCONF (object);
-
-  for ( i = 0; i < N_PROPERTIES; i++)
+  for (guint i = 0; i < N_PROPERTIES; i++)
   {
-    if ( G_IS_VALUE (conf->priv->values + i) )
+    if (G_IS_VALUE (conf->priv->values + i))
       g_value_unset (conf->priv->values + i);
   }
 
   g_free (conf->priv->values);
-
   if (conf->priv->channel != NULL)
     xfconf_shutdown ();
 
-  G_OBJECT_CLASS (xfpm_xfconf_parent_class)->finalize(object);
+  G_OBJECT_CLASS (xfpm_xfconf_parent_class)->finalize (object);
 }
 
 XfpmXfconf *
@@ -702,7 +682,7 @@ xfpm_xfconf_new (void)
 {
   static gpointer xfpm_xfconf_object = NULL;
 
-  if ( G_LIKELY (xfpm_xfconf_object != NULL) )
+  if (G_LIKELY (xfpm_xfconf_object != NULL))
   {
     g_object_ref (xfpm_xfconf_object);
   }
